// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTAUTOCORRECTIONWIDGETS_VERSION_H
#define TEXTAUTOCORRECTIONWIDGETS_VERSION_H

#define TEXTAUTOCORRECTIONWIDGETS_VERSION_STRING "2.0.0"
#define TEXTAUTOCORRECTIONWIDGETS_VERSION_MAJOR 2
#define TEXTAUTOCORRECTIONWIDGETS_VERSION_MINOR 0
#define TEXTAUTOCORRECTIONWIDGETS_VERSION_PATCH 0
#define TEXTAUTOCORRECTIONWIDGETS_VERSION ((2<<16)|(0<<8)|(0))

#endif
